==> dvd95_1.4p0.orig.tar.gz: dvd95-1.4p0/src/globals.h <==
/*==============================================================================

FICHIER     : [globals.h]

DATE        : 2005/12/0008 22:39:30

CREATEUR    : [Linux!jef]

COMMENTAIRE :

================================================================================

==============================================================================*/

#ifndef __GLOBALS_H__
#define __GLOBALS_H__

#include <gnome.h>

enum {
	VIDEO_COL2_PISTE = 0,
	VIDEO_COL3_DUREE,
	VIDEO_COL4_CHAPITRE,
	VIDEO_COL5_LANG,
	VIDEO_COL6_SUB,
	VIDEO_COL7_VIDEO,
	VIDEO_COL8_NO,
	VIDEO_NCOLS
};

enum {
	AUDIO_COL1_CHECK = 0,
	AUDIO_COL2_PISTE,
	AUDIO_COL3_LANG,
	AUDIO_COL4_FORMAT,
	AUDIO_COL5_CANAUX,
	AUDIO_COL6_LANGCODE,	/* Hiden */
	AUDIO_COL7_NO,		/* Hiden */
	AUDIO_NCOLS
};

enum {
	SUB_COL1_CHECK = 0,
	SUB_COL2_PISTE,
	SUB_COL3_LANG,
	SUB_COL4_EXT,
	SUB_COL5_LANGCODE,	/* Hiden */
	SUB_COL6_NO,		/* Hiden */
	SUB_NCOLS
};


enum {
	PHASE2_ARRIERE = 1,
	PHASE2_AVANCER
};

#ifdef __NEED_GLOBALS__
GtkWidget * MainDlg;
int UserStopF = 0;
int UserPauseF = 0;
char DbgLevels[256] = { 0 };
int IgnoreErrors = -1;
int Phase2 = 0;
char Device[1024];
char * TargetDir;
int ImageReadyF = 0;
#else
extern GtkWidget * MainDlg;
extern int UserStopF;
extern int UserPauseF;
extern char DbgLevels[256];
extern int IgnoreErrors;
extern int Phase2;
extern char Device[1024];
extern char * TargetDir;
extern int ImageReadyF;
#endif

#define PPM_FILE	"/tmp/dvd95.ppm"

#define DBG( lvl, x )		if( lvl < 0 || DbgLevels[lvl] ) x
#define IsLevelSet( lvl )	(DbgLevels[lvl])

#endif	/* __GLOBALS_H__ */

==> dvd95_1.5p3.orig.tar.gz: dvd95-1.5p3/src/globals.h <==
/*==============================================================================

FICHIER     : [globals.h]

DATE        : 2005/12/0008 22:39:30

CREATEUR    : [Linux!jef]

COMMENTAIRE :

================================================================================

==============================================================================*/

#ifndef __GLOBALS_H__
#define __GLOBALS_H__

#include <gnome.h>

enum {
	VIDEO_COL2_PISTE = 0,
	VIDEO_COL3_DUREE,
	VIDEO_COL4_CHAPITRE,
	VIDEO_COL5_LANG,
	VIDEO_COL6_SUB,
	VIDEO_COL7_VIDEO,
	VIDEO_COL8_NO,
	VIDEO_NCOLS
};

enum {
	AUDIO_COL1_CHECK = 0,
	AUDIO_COL2_PISTE,
	AUDIO_COL3_LANG,
	AUDIO_COL4_FORMAT,
	AUDIO_COL5_EXTENSION,
	AUDIO_COL6_CANAUX,
	AUDIO_COL7_LANGCODE,	/* Hiden */
	AUDIO_COL8_NO,		/* Hiden */
	AUDIO_NCOLS
};

enum {
	SUB_COL1_CHECK = 0,
	SUB_COL2_PISTE,
	SUB_COL3_LANG,
	SUB_COL4_EXT,
	SUB_COL5_LANGCODE,	/* Hiden */
	SUB_COL6_NO,		/* Hiden */
	SUB_NCOLS
};


enum {
	PHASE2_ARRIERE = 1,
	PHASE2_AVANCER
};

#ifdef __NEED_GLOBALS__
GtkWidget * MainDlg;
int UserStopF = 0;
int UserPauseF = 0;
char DbgLevels[256] = { 0 };
int IgnoreErrors = -1;
int Phase2 = 0;
char Device[1024];
char * TargetDir;
int ImageReadyF = 0;
int DeviceSpecifiedF = 0; /* --isodir or --dvddir specified by argument */
#else
extern GtkWidget * MainDlg;
extern int UserStopF;
extern int UserPauseF;
extern char DbgLevels[256];
extern int IgnoreErrors;
extern int Phase2;
extern char Device[1024];
extern char * TargetDir;
extern int ImageReadyF;
extern int DeviceSpecifiedF;
#endif

#define PPM_FILE	"/tmp/dvd95.ppm"

#define DBG( lvl, x )		if( lvl < 0 || DbgLevels[lvl] ) x
#define IsLevelSet( lvl )	(DbgLevels[lvl])

#endif	/* __GLOBALS_H__ */
